@@ -1,6 +1,9 @@
+from .ArgConfigParse import *
+from . import ArgConfigParse
 from .ArgConfigParse import ConfigFile
 from .ArgConfigParse import CmdArgs
 from .ArgConfigParse import merge_dict
 from .ArgConfigParse import fullPath
 from .ArgConfigParse import write
 
+
